@@ -20,7 +20,8 @@ if platform == "linux" or platform == "linux2":
 else:
     from .globals import java_windows as java
 
-from .globals import hvac_url, hvac_token, hvac_secret_id, hvac_role_id, hvac_connections_path, hvac_connections_mountpoint
+from .globals import hvac_url, hvac_token, hvac_secret_id, hvac_role_id, hvac_connections_path, \
+    hvac_connections_mountpoint, hvac_token_env_var, hvac_secret_env_var, hvac_role_id_env_var
 
 
 def create_saspyconn(sasobjsp_host, sasobjsp_port, java=java):
@@ -553,6 +554,12 @@ def get_hvac_client(hvac_url: str = hvac_url,
                     ldap_password: str = None,
                     verify=True,
                     **kwargs):
+    if not token:
+        token = os.environ.get(hvac_token_env_var, default=None)
+    if not hvac_role_id:
+        hvac_role_id = os.environ.get(hvac_role_id_env_var, default=None)
+    if not hvac_secret_id:
+        hvac_secret_id = os.environ.get(hvac_secret_env_var, default=None)
     try:
         if token:
             client = hvac.Client(url=hvac_url, token=token, namespace=namespace, verify=verify)
